// (C) Copyright 2002-2007 by Autodesk, Inc. 
//
// Permission to use, copy, modify, and distribute this software in
// object code form for any purpose and without fee is hereby granted, 
// provided that the above copyright notice appears in all copies and 
// that both that copyright notice and the limited warranty and
// restricted rights notice below appear in all supporting 
// documentation.
//
// AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS. 
// AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
// MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK, INC. 
// DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
// UNINTERRUPTED OR ERROR FREE.
//
// Use, duplication, or disclosure by the U.S. Government is subject to 
// restrictions set forth in FAR 52.227-19 (Commercial Computer
// Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
// (Rights in Technical Data and Computer Software), as applicable.
//

//-----------------------------------------------------------------------------
//----- DynAngle.cpp :  CDynAngle
//-----------------------------------------------------------------------------
#include "StdAfx.h"
#include "DynAngle.h"

//----- CDynAngle
STDMETHODIMP CDynAngle::InterfaceSupportsErrorInfo(REFIID riid) {
	static const IID* arr [] = { &IID_IDynAngle } ;

	for ( int i =0 ; i < sizeof (arr) / sizeof (arr [0]) ; i++ ) {
		if ( InlineIsEqualGUID (*arr [i], riid) )
			return (S_OK) ;
	}
	return (S_FALSE) ;
}

//----- IDynamicProperty
STDMETHODIMP CDynAngle::GetGUID (GUID *pPropGUID) {
	if ( pPropGUID == NULL )
		return (E_POINTER) ;

	memcpy (pPropGUID, &CLSID_DynAngle, sizeof(GUID)) ;

	return (S_OK) ;
}

STDMETHODIMP CDynAngle::GetDisplayName (BSTR *pBstrName) {
	if ( pBstrName == NULL )
		return (E_POINTER) ;

	*pBstrName =::SysAllocString (L" CDynAngle") ;

	return (S_OK) ;
}

STDMETHODIMP CDynAngle::IsPropertyEnabled (IUnknown *pUnk, BOOL *pbEnabled) {
	if ( pUnk == NULL )
		return (E_INVALIDARG) ;
	if ( pbEnabled == NULL )
		return (E_POINTER) ;

	*pbEnabled =TRUE ;

	return (S_OK) ;
}

STDMETHODIMP CDynAngle::IsPropertyReadOnly (BOOL *pbReadOnly) {
	if ( pbReadOnly == NULL )
		return (E_POINTER) ;

	*pbReadOnly =FALSE ;

	return (S_OK) ;
}

STDMETHODIMP CDynAngle::GetDescription (BSTR *pBstrName) {
	if ( pBstrName == NULL )
		return (E_POINTER) ;

	*pBstrName =::SysAllocString (L"  CDynDistance") ;

	return (S_OK) ;
}

STDMETHODIMP CDynAngle::GetCurrentValueName (BSTR *pBstrName) {
	if ( pBstrName == NULL )
		return (E_POINTER) ;
  //////////////////////////////////////////////////////////////////////////
  //                
  //////////////////////////////////////////////////////////////////////////
  *pBstrName =::SysAllocString (L"ACAD_ANGLE") ;

  return (S_OK) ; 
}

STDMETHODIMP CDynAngle::GetCurrentValueType (VARTYPE *pVarType) {
	if ( pVarType == NULL )
		return (E_POINTER) ;
  //////////////////////////////////////////////////////////////////////////
  //                 
  //////////////////////////////////////////////////////////////////////////
  *pVarType = VT_USERDEFINED;

  return (S_OK) ;
}

STDMETHODIMP CDynAngle::GetCurrentValueData (IUnknown *pUnk, VARIANT *pVarData) {
	if ( pUnk == NULL )
		return (E_INVALIDARG) ;
	if ( pVarData == NULL )
		return (E_POINTER) ;
  //////////////////////////////////////////////////////////////////////////
  //          
  //////////////////////////////////////////////////////////////////////////
  V_VT(pVarData) = VT_R8 ;
  _variant_t l_sel;
  if (SUCCEEDED(m_pNotify->GetCurrentSelectionSet(&l_sel))) {
    V_R8(pVarData) = GetSelectedAngle(&l_sel);
  } else {
    V_R8(pVarData) = 0.0;
  }
  return (S_OK) ;
}

STDMETHODIMP CDynAngle::SetCurrentValueData (IUnknown *pUnk, const VARIANT varData) {
	if ( pUnk == NULL )
		return (E_INVALIDARG) ;
	

	return (S_OK) ;
}

STDMETHODIMP CDynAngle::Connect (IDynamicPropertyNotify2 *pSink) {
	if ( pSink == NULL )
		return (E_POINTER) ;
	m_pNotify =pSink ;
	m_pNotify->AddRef () ;
	return (S_OK) ;
}

STDMETHODIMP CDynAngle::Disconnect () {
	if ( m_pNotify ) {
		m_pNotify->Release () ;
		m_pNotify= NULL ;
	}
	return (S_OK) ;
}



